.. audiofile documentation master file

.. include:: ../README.rst
    :end-line: 16

.. toctree::
    :caption: Getting started
    
    installation
    usage
    contributing
    version-history

.. toctree::
    :caption: API Documentation

    api
